volutil: neuroimaging volume utilities
======================================

Scripts are:

* vol-info: print basic information about a volume
* vol-stats: print basic statistics of a volume
* vol-cat: print the voxel values in volumes
* vol-hist: dump an integer histogram for a volume
* vol-vol: calculate volumes of ROIs
* vol-dice: calculate Dice coefficients for ROI overlaps
* vol-tr: change values in a volume
* vol-slice: create slice images from a volume, with an optional overlay
